################################################################################
Name:           jss
################################################################################

%global         product_id dogtag-jss

# Upstream version number:
%global         major_version 5
%global         minor_version 5
%global         update_version 0

# Downstream release number:
# - development/stabilization (unsupported): 0.<n> where n >= 1
# - GA/update (supported): <n> where n >= 1
%define         rel 2

# Development phase:
# - development (unsupported): alpha<n> where n >= 1
# - stabilization (unsupported): beta<n> where n >= 1
# - GA/update (supported): <none>
%undefine       phase

%undefine       timestamp
%undefine       commit_id

Summary:        Java Security Services (JSS)
URL:            https://github.com/dogtagpki/jss
Group:          Development/Java
License:        MPLv1.1 or GPLv2+ or LGPLv2+
Version:        %{major_version}.%{minor_version}.%{update_version}
Release:        %mkrel %{rel}%{?phase:.}%{?phase}%{?timestamp:.}%{?timestamp}%{?commit_id:.}%{?commit_id}

# To generate the source tarball:
# $ git clone https://github.com/dogtagpki/jss.git
# $ cd jss
# $ git tag v4.5.<z>
# $ git push origin v4.5.<z>
# Then go to https://github.com/dogtagpki/jss/releases and download the source
# tarball.
Source:         https://github.com/dogtagpki/jss/archive/v%{version}%{?phase:-}%{?phase}/jss-%{version}%{?phase:-}%{?phase}.tar.gz

# To create a patch for all changes since a version tag:
# $ git format-patch \
#     --stdout \
#     <version tag> \
#     > jss-VERSION-RELEASE.patch
# Patch: jss-VERSION-RELEASE.patch

################################################################################
# Java
################################################################################

%define java_devel java-21-openjdk-devel
%define java_headless java-21-openjdk-headless
%define java_home %{_jvmdir}/jre-21-openjdk

################################################################################
# Build Options
################################################################################

# By default the javadoc package will be built unless --without javadoc
# option is specified.

%bcond_without javadoc

# By default the build will not execute unit tests unless --with tests
# option is specified.

%bcond_with tests

################################################################################
# Build Dependencies
################################################################################

BuildRequires:  make
BuildRequires:  cmake >= 3.14
BuildRequires:  zip
BuildRequires:  unzip

BuildRequires:  gcc-c++
BuildRequires:  nss-devel >= 3.66
BuildRequires:  nss >= 3.66

BuildRequires:  %{java_devel}
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-jdk14)

%description
Java Security Services (JSS) is a java native interface which provides a bridge
for java-based applications to use native Network Security Services (NSS).
This only works with gcj. Other JREs require that JCE providers be signed.

################################################################################
%package -n %{product_id}
################################################################################

Summary:        Java Security Services (JSS)

Requires:       nss >= 3.66

Requires:       %{java_headless}
Requires:       mvn(org.apache.commons:commons-lang3)
Requires:       mvn(org.slf4j:slf4j-api)
Requires:       mvn(org.slf4j:slf4j-jdk14)

Obsoletes:      jss < %{version}-%{release}
Provides:       jss = %{version}-%{release}
Provides:       jss = %{major_version}.%{minor_version}
Provides:       %{product_id} = %{major_version}.%{minor_version}

Conflicts:      ldapjdk < 4.20
Conflicts:      idm-console-framework < 1.2
Conflicts:      pki-base < 10.10.0

%description -n %{product_id}
Java Security Services (JSS) is a java native interface which provides a bridge
for java-based applications to use native Network Security Services (NSS).
This only works with gcj. Other JREs require that JCE providers be signed.

%if %{with javadoc}
################################################################################
%package -n %{product_id}-javadoc
################################################################################

Summary:        Java Security Services (JSS) Javadocs

Obsoletes:      jss-javadoc < %{version}-%{release}
Provides:       jss-javadoc = %{version}-%{release}
Provides:       jss-javadoc = %{major_version}.%{minor_version}
Provides:       %{product_id}-javadoc = %{major_version}.%{minor_version}

%description -n %{product_id}-javadoc
This package contains the API documentation for JSS.
%endif

%if %{with tests}
################################################################################
%package -n %{product_id}-tests
################################################################################

Summary:        Java Security Services (JSS) Tests

BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
BuildRequires:  mvn(org.opentest4j:opentest4j)

%description -n %{product_id}-tests
This package provides test suite for JSS.

# with tests
%endif

################################################################################
%prep
################################################################################

%autosetup -n jss-%{version}%{?phase:-}%{?phase} -p 1

# disable native modules since they will be built by CMake
%pom_disable_module native
%pom_disable_module symkey

# do not ship examples
%pom_disable_module examples

# flatten-maven-plugin is not available in RPM
%pom_remove_plugin org.codehaus.mojo:flatten-maven-plugin

%pom_disable_module tomcat

%pom_disable_module tomcat-9.0

################################################################################
%build
################################################################################

# Set build flags for CMake
# (see /usr/lib/rpm/macros.d/macros.cmake)
%set_build_flags

export JAVA_HOME=%{java_home}

# Enable compiler optimizations
export BUILD_OPT=1

# Generate symbolic info for debuggers
CFLAGS="-g $RPM_OPT_FLAGS"
%ifarch %{arm} %{ix86}
CFLAGS="$CFLAGS -Wno-incompatible-pointer-types"
%endif
export CFLAGS

# Check if we're in FIPS mode
modutil -dbdir /etc/pki/nssdb -chkfips true | grep -q enabled && export FIPS_ENABLED=1

# build Java code, run Java tests, and build Javadoc with Maven
%mvn_build %{!?with_tests:-f} %{!?with_javadoc:-j}

# create links to Maven-built classes for CMake
mkdir -p %{_vpath_builddir}/classes/jss
ln -sf ../../../base/target/classes/org %{_vpath_builddir}/classes/jss
%if %{with tests}
mkdir -p %{_vpath_builddir}/classes/tests
ln -sf ../../../base/target/test-classes/org %{_vpath_builddir}/classes/tests
%endif

# create links to Maven-built JAR files for CMake
ln -sf ../base/target/jss.jar %{_vpath_builddir}
%if %{with tests}
ln -sf ../base/target/jss-tests.jar %{_vpath_builddir}
%endif

# create links to Maven-built headers for CMake
mkdir -p %{_vpath_builddir}/include/jss
ln -sf ../../../base/target/include/_jni %{_vpath_builddir}/include/jss/_jni

# mark Maven-built targets so that CMake will not rebuild them
mkdir -p %{_vpath_builddir}/.targets
touch %{_vpath_builddir}/.targets/finished_generate_java
%if %{with tests}
touch %{_vpath_builddir}/.targets/finished_tests_generate_java
%endif
%if %{with javadoc}
touch %{_vpath_builddir}/.targets/finished_generate_javadocs
%endif

# build native code and run native tests with CMake
./build.sh \
    %{?_verbose:-v} \
    --work-dir=%{_vpath_builddir} \
    --prefix-dir=%{_prefix} \
    --include-dir=%{_includedir} \
    --lib-dir=%{_libdir} \
    --sysconf-dir=%{_sysconfdir} \
    --share-dir=%{_datadir} \
    --cmake=%{__cmake} \
    --java-home=%{java_home} \
    --jni-dir=%{_jnidir} \
    --version=%{version} \
    --without-java \
    --without-javadoc \
    %{!?with_tests:--without-tests} \
    dist

################################################################################
%install
################################################################################

# install Java binaries and Javadoc
%mvn_install

# install jss.jar
mkdir -p %{buildroot}%{_javadir}/jss
cp base/target/jss.jar %{buildroot}%{_javadir}/jss/jss.jar

# create links for backward compatibility
mkdir -p %{buildroot}%{_jnidir}
ln -sf ../../..%{_javadir}/jss/jss.jar %{buildroot}%{_jnidir}/jss.jar

mkdir -p %{buildroot}%{_libdir}/jss
ln -sf ../../..%{_javadir}/jss/jss.jar %{buildroot}%{_libdir}/jss/jss.jar

# install native binaries
./build.sh \
    %{?_verbose:-v} \
    --work-dir=%{_vpath_builddir} \
    --install-dir=%{buildroot} \
    --without-java \
    install

# install tests binaries
%if %{with tests}
mkdir -p %{buildroot}%{_datadir}/jss/tests/lib
cp base/target/jss-tests.jar %{buildroot}%{_datadir}/jss/tests/lib
%endif

################################################################################
%files -n %{product_id} -f .mfiles
################################################################################

%doc jss.html
%license MPL-1.1.txt gpl.txt lgpl.txt symkey/LICENSE
%{_javadir}/jss/jss.jar
%{_jnidir}/jss.jar
%{_libdir}/jss/jss.jar
%{_libdir}/jss/libjss.so
%{_libdir}/jss/libjss-symkey.so

%if %{with javadoc}
################################################################################
%files -n %{product_id}-javadoc -f .mfiles-javadoc
################################################################################
%endif

%if %{with tests}
################################################################################
%files -n %{product_id}-tests
################################################################################

%{_datadir}/jss/tests/

# with tests
%endif

################################################################################



%changelog
* Sun Jun 29 2025 umeabot <umeabot> 5.5.0-2.mga10
+ Revision: 2223322
- Mageia 10 Mass Rebuild

* Thu May 23 2024 ns80 <ns80> 5.5.0-1.mga10
+ Revision: 2066560
- new version 5.5.0 for java 21

* Sat Dec 10 2022 daviddavid <daviddavid> 5.2.0-2.mga9
+ Revision: 1920320
- fix release tag

* Sat Dec 10 2022 neoclust <neoclust> 5.2.0-1.1.mga9
+ Revision: 1920231
- New version 5.2.0

* Sat Mar 26 2022 umeabot <umeabot> 4.8.1-2.mga9
+ Revision: 1828392
- Mageia 9 Mass Rebuild

* Mon Mar 01 2021 daviddavid <daviddavid> 4.8.1-1.mga9
+ Revision: 1694810
- Rebase to upstream stable JSS v4.8.1

* Sat Sep 05 2020 daviddavid <daviddavid> 4.7.2-1.mga8
+ Revision: 1622411
- new version: 4.7.2
- Rebuilt for JDK-11
+ danf <danf>
- Switch URLs from http: to https:

* Mon Feb 17 2020 umeabot <umeabot> 4.6.2-2.mga8
+ Revision: 1537127
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags
- build with new cmake macros

* Sat Oct 26 2019 daviddavid <daviddavid> 4.6.2-1.mga8
+ Revision: 1455868
- new version: 4.6.2, fixes CVE-2019-14823

* Fri Aug 30 2019 daviddavid <daviddavid> 4.6.1-1.mga8
+ Revision: 1435477
- new version: 4.6.1

* Fri Jul 19 2019 daviddavid <daviddavid> 4.5.3-1.mga8
+ Revision: 1422910
- new version: 4.5.3
- add AIA OCSP certificate checking patch

* Fri Feb 08 2019 daviddavid <daviddavid> 4.5.2-1.mga7
+ Revision: 1364295
- new version: 4.5.2

* Sun Sep 23 2018 umeabot <umeabot> 4.4.3-2.mga7
+ Revision: 1298399
- Mageia 7 Mass Rebuild

* Sat Apr 21 2018 daviddavid <daviddavid> 4.4.3-1.mga7
+ Revision: 1220723
- new version: 4.4.3 (sync with fc29)

* Thu Mar 24 2016 daviddavid <daviddavid> 4.2.6-9.mga6
+ Revision: 994709
- add patch from fedora to fix javadoc build
- use __isa_bits macro to check for 64-bit arch. Unblocks aarch64 and ppc64le.

* Fri Mar 11 2016 daviddavid <daviddavid> 4.2.6-8.mga6
+ Revision: 989272
- fix javadoc build on JDK 8 (disabling the super-strict doclint checks)
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Aug 25 2015 daviddavid <daviddavid> 4.2.6-7.mga6
+ Revision: 869244
- sync with fc23:
  * Bugzilla Bug #1040640 - Incorrect OIDs for SHA2 algorithms
    (cfu for jnimeh@gmail.com)
  * Bugzilla Bug #1133718 - Key strength validation is not performed for RC4
    algorithm (nkinder)
  * Bugzilla Bug #816396 - Provide Tomcat support for TLS v1.1 and
    TLS v1.2 via NSS through JSS (cfu)

* Wed Oct 15 2014 umeabot <umeabot> 4.2.6-6.mga5
+ Revision: 744173
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2.6-5.mga5
+ Revision: 680884
- Mageia 5 Mass Rebuild

* Sun Dec 29 2013 dmorgan <dmorgan> 4.2.6-4.mga4
+ Revision: 563214
- New version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ luigiwalser <luigiwalser>
- update java BRs

* Fri Jan 18 2013 umeabot <umeabot> 0:4.2.5-5.mga3
+ Revision: 389250
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 03 2011 dmorgan <dmorgan> 0:4.2.5-4.mga2
+ Revision: 175568
- Install jar files in %%javadir too
  Clean spec file
  Remove gcj support

* Fri Jan 21 2011 dmorgan <dmorgan> 0:4.2.5-3.0.6.mga1
+ Revision: 28516
- imported package jss


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0:4.2.5-3.0.6mdv2011.0
+ Revision: 606116
- rebuild

* Thu Mar 25 2010 Oden Eriksson <oeriksson@mandriva.com> 0:4.2.5-3.0.5mdv2010.1
+ Revision: 527395
- rebuilt against nss-3.12.6

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:4.2.5-3.0.4mdv2010.1
+ Revision: 523132
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0:4.2.5-3.0.3mdv2010.0
+ Revision: 425474
- rebuild

* Fri Apr 10 2009 Funda Wang <fwang@mandriva.org> 0:4.2.5-3.0.2mdv2009.1
+ Revision: 365545
- rediff target source patch

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 0:4.2.5-3.0.2mdv2009.0
+ Revision: 264756
- rebuild early 2009.0 package (before pixel changes)

* Tue May 06 2008 David Walluck <walluck@mandriva.org> 0:4.2.5-0.0.2mdv2009.0
+ Revision: 201749
- create %%{_libdir} not %%{_jnidir} again
- 4.2.5

* Sat Jan 05 2008 David Walluck <walluck@mandriva.org> 0:3.4-10mdv2008.1
+ Revision: 145644
- allow javadocs to fail so that build passes

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)
    - remove unnecessary Requires(post) on java-gcj-compat


* Thu Mar 08 2007 Christiaan Welvaart <cjw@daneel.dyndns.org>
+ 2007-03-08 19:34:50 (138458)
- patch0: fix build with separate nss package
- Import jss

* Sun Jun 04 2006 David Walluck <walluck@mandriva.org> 0:3.4-6mdv2007.0
- rebuild for libgcj.so.7

* Mon Feb 06 2006 David Walluck <walluck@mandriva.org> 0:3.4-5mdk
- use standalone nsinstall

* Sun Jan 15 2006 David Walluck <walluck@mandriva.org> 0:3.4-4mdk
- fix path to aot-compile-rpm
- BuildRequires: java-devel

* Fri Oct 28 2005 David Walluck <walluck@mandriva.org> 0:3.4-3mdk
- rebuild

* Tue Sep 13 2005 David Walluck <walluck@mandriva.org> 0:3.4-2mdk
- add compatibility symlink to jss34.jar
- build libjss3.so
- fix javadoc building

* Mon Sep 12 2005 David Walluck <walluck@mandriva.org> 0:3.4-1mdk
- release

